@@ -12,11 +12,6 @@ BIDIRECTIONAL_FACT = "BiDirectional"
 DEFAULT_VALIDATOR = r'(.|\n)*'
 ACT_TIME_FORMAT = "%Y-%m-%dT%H:%M:%SZ"
 
-RE_UUID_MATCH = r'^[a-z0-9]{8}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{12}$'
-RE_UUID = r'(?P<uuid>[a-z0-9]{8}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{12})'
-RE_TIMESTAMP_MATCH = r'^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}.\d{3}Z$'
-RE_TIMESTAMP = r'(?P<timestamp>\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}.\d{3}Z)'
-
 from act.api import utils
 from act.api import schema
 from act.api import base
